SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE=`TRADITIONAL,ALLOW_INVALID_DATES`;

DROP SCHEMA IF EXISTS `arcyd` ;
CREATE SCHEMA IF NOT EXISTS `arcyd` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci ;
USE `arcyd` ;

-- -----------------------------------------------------
-- Table `arcyd`.`Usuario`s
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`Usuario` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`Usuario` (
  `idUsuario` INT NOT NULL AUTO_INCREMENT,
  `numSocio` VARCHAR(45) NULL ,
  `dni` VARCHAR(45) NULL ,
  `nombre` VARCHAR(45) NULL ,
  `apellido` VARCHAR(45) NULL ,
  `direccion` VARCHAR(45) NULL ,
  `telefono` VARCHAR(45) NULL ,
  `email` VARCHAR(45) NULL ,
  `password` VARCHAR(45) NULL ,
    `perfil` VARCHAR(45) NULL ,
  PRIMARY KEY (`idUsuario`) )
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `arcyd`.`Profesor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`Profesor` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`Profesor` (
  `idProfesor` INT NOT NULL AUTO_INCREMENT,
  `nombre` VARCHAR(45) NULL ,
  `apellido` VARCHAR(45) NULL ,
  `telefono` VARCHAR(45) NULL ,
  `email` VARCHAR(45) NULL ,
  PRIMARY KEY (`idProfesor`) )
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `arcyd`.`Localizacion`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`Localizacion` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`Localizacion` (
  `idLocalizacion` INT NOT NULL AUTO_INCREMENT,
  `tipo` VARCHAR(45) NULL ,
  PRIMARY KEY (`idLocalizacion`) )
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `arcyd`.`Actividad`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`Actividad` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`Actividad` (
  `idActividad` INT NOT NULL AUTO_INCREMENT,
  `nombre` VARCHAR(45) NULL ,
  `descripcion` VARCHAR(1000) NULL ,
  `Profesor_idProfesor` INT NOT NULL ,
  `Localizacion_idLocalizacion` INT NOT NULL ,
  PRIMARY KEY (`idActividad`) ,
  CONSTRAINT `fk_Actividad_Profesor1`
    FOREIGN KEY (`Profesor_idProfesor` )
    REFERENCES `arcyd`.`Profesor` (`idProfesor` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Actividad_Pista1`
    FOREIGN KEY (`Localizacion_idLocalizacion` )
    REFERENCES `arcyd`.`Localizacion` (`idLocalizacion` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB DEFAULT CHARSET=utf8;

CREATE INDEX `fk_Actividad_Profesor1_idx` ON `arcyd`.`Actividad` (`Profesor_idProfesor` ASC) ;

CREATE INDEX `fk_Actividad_Pista1_idx` ON `arcyd`.`Actividad` (`Localizacion_idLocalizacion` ASC) ;


-- -----------------------------------------------------
-- Table `arcyd`.`EstadoReserva`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`EstadoReserva` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`EstadoReserva` (
  `idEstadoReserva` INT NOT NULL AUTO_INCREMENT,
  `estado` VARCHAR(45) NULL ,
  PRIMARY KEY (`idEstadoReserva`) )
ENGINE = InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `arcyd`.`ReservaActividad`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`ReservaActividad` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`ReservaActividad` (
  `idReservaActividad` INT NOT NULL AUTO_INCREMENT,
  `fechaInscripcion` DATE NULL ,
  `fechaBaja` VARCHAR(45) NULL ,
  `EstadoReserva_idEstadoReserva` INT NOT NULL ,
  `Usuario_idUsuario` INT NOT NULL ,
  `Actividad_idActividad` INT NOT NULL ,
  `HorarioActividad_idHorarioActividad` INT NOT NULL ,
  PRIMARY KEY (`idReservaActividad`) ,
  CONSTRAINT `fk_ReservaActividad_Actividad1`
    FOREIGN KEY (`Actividad_idActividad` )
    REFERENCES `arcyd`.`Actividad` (`idActividad` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ReservaActividad_Usuario1`
    FOREIGN KEY (`Usuario_idUsuario` )
    REFERENCES `arcyd`.`Usuario` (`idUsuario` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ReservaActividad_EstadoReserva1`
    FOREIGN KEY (`EstadoReserva_idEstadoReserva` )
    REFERENCES `arcyd`.`EstadoReserva` (`idEstadoReserva` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_ReservaActividad_HorarioActividad1`
    FOREIGN KEY (`HorarioActividad_idHorarioActividad` )
    REFERENCES `arcyd`.`HorarioActividad` (`idHorarioActividad` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB DEFAULT CHARSET=utf8;

CREATE INDEX `fk_ReservaActividad_Actividad1_idx` ON `arcyd`.`ReservaActividad` (`Actividad_idActividad` ASC) ;

CREATE INDEX `fk_ReservaActividad_Usuario1_idx` ON `arcyd`.`ReservaActividad` (`Usuario_idUsuario` ASC) ;

CREATE INDEX `fk_ReservaActividad_EstadoReserva1_idx` ON `arcyd`.`ReservaActividad` (`EstadoReserva_idEstadoReserva` ASC) ;



-- -----------------------------------------------------
-- Table `arcyd`.`Pista`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`Pista` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`Pista` (
  `idPista` INT NOT NULL AUTO_INCREMENT,
  `nombre` VARCHAR(45) NULL ,
  `descripcion` VARCHAR(1000) NULL ,
  `numPistas` INT NULL ,
  `Localizacion_idLocalizacion` INT NOT NULL ,
  PRIMARY KEY (`idPista`) ,
  CONSTRAINT `fk_Pista_Localizacion1`
    FOREIGN KEY (`Localizacion_idLocalizacion` )
    REFERENCES `arcyd`.`Localizacion` (`idLocalizacion` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB DEFAULT CHARSET=utf8;

CREATE INDEX `fk_Pista_Localizacion1_idx` ON `arcyd`.`Pista` (`Localizacion_idLocalizacion` ASC) ;


-- -----------------------------------------------------
-- Table `arcyd`.`ReservaPista`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`ReservaPista` ;


CREATE  TABLE IF NOT EXISTS `arcyd`.`ReservaPista` (
  `idReservaPista` INT NOT NULL AUTO_INCREMENT,
  `Usuario_idUsuario` int(11) NOT NULL,
  `Pista_idPista` int(11) NOT NULL,
  `fechaReserva` date DEFAULT NULL,
  `horaReserva` varchar(45) DEFAULT NULL,
  `EstadoReserva_idEstadoReserva` int(11) NOT NULL,
  PRIMARY KEY (`idReservaPista`),
  KEY `fk_ReservaActividad_Usuario1_idx` (`Usuario_idUsuario`),
  KEY `fk_ReservaActividad_EstadoReserva1_idx` (`EstadoReserva_idEstadoReserva`),
  KEY `fk_ReservaPista_Pista1_idx` (`Pista_idPista`),
  CONSTRAINT `fk_ReservaActividad_EstadoReserva10` FOREIGN KEY (`EstadoReserva_idEstadoReserva`) REFERENCES `EstadoReserva` (`idEstadoReserva`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `fk_ReservaActividad_Usuario10` FOREIGN KEY (`Usuario_idUsuario`) REFERENCES `Usuario` (`idUsuario`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  CONSTRAINT `fk_ReservaPista_Pista1` FOREIGN KEY (`Pista_idPista`) REFERENCES `Pista` (`idPista`) ON DELETE NO ACTION ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


-- -----------------------------------------------------
-- Table `arcyd`.`Noticia`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`Noticia` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`Noticia` (
  `idNoticia` INT NOT NULL AUTO_INCREMENT,
  `titulo` VARCHAR(45) NULL ,
  `descripcion` VARCHAR(1000) NULL ,
  `fecha` DATETIME DEFAULT CURRENT_TIMESTAMP ,
  PRIMARY KEY (`idNoticia`) )
ENGINE = InnoDB DEFAULT CHARSET=utf8;





-- -----------------------------------------------------
-- Table `arcyd`.`HorarioActividad`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `arcyd`.`HorarioActividad` ;

CREATE  TABLE IF NOT EXISTS `arcyd`.`HorarioActividad` (
  `idHorarioActividad` INT NOT NULL AUTO_INCREMENT,
  `dia` VARCHAR(45) NULL ,
  `hora` VARCHAR(45) NULL ,
  `Actividad_idActividad` INT NOT NULL ,
  PRIMARY KEY (`idHorarioActividad`) ,
  CONSTRAINT `fk_HorarioActividad_Actividad1`
    FOREIGN KEY (`Actividad_idActividad` )
    REFERENCES `arcyd`.`Actividad` (`idActividad` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB DEFAULT CHARSET=utf8;

CREATE INDEX `fk_HorarioActividad_Actividad1_idx` ON `arcyd`.`HorarioActividad` (`Actividad_idActividad` ASC) ;

ALTER TABLE `arcyd`.`Actividad` 
ADD UNIQUE INDEX `nombre_UNIQUE` (`nombre` ASC) ;

ALTER TABLE `arcyd`.`Pista` 
ADD UNIQUE INDEX `nombre_UNIQUE` (`nombre` ASC) ;



USE `arcyd` ;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;



/*
-- Query: SELECT * FROM arcyd.EstadoReserva
LIMIT 0, 1000

-- Date: 2013-03-28 11:41
*/
INSERT INTO `ARCYD`.`EstadoReserva` (`idEstadoReserva`,`estado`) VALUES (1,'SOLICITADA');
INSERT INTO `ARCYD`.`EstadoReserva` (`idEstadoReserva`,`estado`) VALUES (2,'CONFIRMADA');
INSERT INTO `ARCYD`.`EstadoReserva` (`idEstadoReserva`,`estado`) VALUES (3,'CANCELADA');
INSERT INTO `ARCYD`.`EstadoReserva` (`idEstadoReserva`,`estado`) VALUES (4,'BAJA SOLICITADA');

/*
-- Query: SELECT * FROM arcyd.Localizacion
LIMIT 0, 1000

-- Date: 2013-03-28 11:42
*/
INSERT INTO `ARCYD`.`Localizacion` (`idLocalizacion`,`tipo`) VALUES (1,'PISTAS TENIS');
INSERT INTO `ARCYD`.`Localizacion` (`idLocalizacion`,`tipo`) VALUES (2,'PISTAS LIBRES');
INSERT INTO `ARCYD`.`Localizacion` (`idLocalizacion`,`tipo`) VALUES (3,'PISTAS PADEL');
INSERT INTO `ARCYD`.`Localizacion` (`idLocalizacion`,`tipo`) VALUES (4,'PISTAS SQUATCH');
INSERT INTO `ARCYD`.`Localizacion` (`idLocalizacion`,`tipo`) VALUES (5,'GIMNSASIO');
INSERT INTO `ARCYD`.`Localizacion` (`idLocalizacion`,`tipo`) VALUES (6,'SALA POLIVALENTE');



/*
-- Query: SELECT * FROM arcyd.Pista
LIMIT 0, 1000

-- Date: 2013-03-28 11:42
*/
INSERT INTO `ARCYD`.`Pista` (`idPista`,`nombre`,`descripcion`,`numPistas`,`Localizacion_idLocalizacion`) VALUES (1,'Tenis','La pista tiene 23,77 metros de largo. El ancho vara segn se juegue individuales (8,23 metros) o dobles (10.97 metros). La red divisoria debe encontrarse a una altura de 0,914 m al centro y 1,07 m en los postes que la sostienen.',3,1);
INSERT INTO `ARCYD`.`Pista` (`idPista`,`nombre`,`descripcion`,`numPistas`,`Localizacion_idLocalizacion`) VALUES (2,'Baloncesto','La  pista de baloncesto tiene que ser una superficie dura, plana, rectangular y libre de obstculos, con 15 m de ancho y 28 m de longitud',2,2);
INSERT INTO `ARCYD`.`Pista` (`idPista`,`nombre`,`descripcion`,`numPistas`,`Localizacion_idLocalizacion`) VALUES (3,'Padel','La pista de padel es un rectngulo dividido en su mitad por una red. A ambos lados de ella, paralelas a la misma y a una distancia de 6,95 m estn las lneas de servicio. El rea entre la red y las lneas de servicio est dividida en su mitad por una lnea perpendicular a estas, llamada lnea central de saque, que divide esta rea en dos zonas iguales. Todas las lneas tienen un ancho de cinco cm de ancho y sern de color claro fcilmente distinguible del pavimento.',3,3);
INSERT INTO `ARCYD`.`Pista` (`idPista`,`nombre`,`descripcion`,`numPistas`,`Localizacion_idLocalizacion`) VALUES (4,'Squatch','Las dimensiones de una pista de squash son 9,75 m de largo por 6,40 m de ancho. Altura del borde superior de la lnea de saque sobre la pared frontal: 1,83 m.',3,4);
INSERT INTO `ARCYD`.`Pista` (`idPista`,`nombre`,`descripcion`,`numPistas`,`Localizacion_idLocalizacion`) VALUES (5,'Ftbol sala','La pista est compuesta por dos lneas de banda y dos lneas de meta, formando un rectngulo. La longitud tiene que estar entre los 25 metros y los 42 metros como mximo. La anchura tiene que estar entre los 16 metros y los 25 metros.',1,2);


/*
-- Query: SELECT * FROM arcyd.Profesor
LIMIT 0, 1000

-- Date: 2013-03-28 11:43
*/
INSERT INTO `ARCYD`.`Profesor` (`idProfesor`,`nombre`,`apellido`,`telefono`,`email`) VALUES (1,'Pilar','Gmez','633893213','pilar.gomez@gmail.com');
INSERT INTO `ARCYD`.`Profesor` (`idProfesor`,`nombre`,`apellido`,`telefono`,`email`) VALUES (2,'Alvaro','Prez','632435654','alvaro.perez@gmail.com');
INSERT INTO `ARCYD`.`Profesor` (`idProfesor`,`nombre`,`apellido`,`telefono`,`email`) VALUES (3,'Marcos','Gonzlez','913784323','marcos.gonzalez@gmail.com');
INSERT INTO `ARCYD`.`Profesor` (`idProfesor`,`nombre`,`apellido`,`telefono`,`email`) VALUES (4,'Maria','Lpez Lpez','932343321','maria.lopez@yahoo.es');
INSERT INTO `ARCYD`.`Profesor` (`idProfesor`,`nombre`,`apellido`,`telefono`,`email`) VALUES (5,'Francisco','Ruiz','932358321','paco.ruiz@yahoo.es');

/*
-- Query: SELECT * FROM arcyd.Actividad
LIMIT 0, 1000

-- Date: 2013-03-28 11:39
*/
INSERT INTO `ARCYD`.`Actividad` (`idActividad`,`nombre`,`descripcion`,`Profesor_idProfesor`,`Localizacion_idLocalizacion`) VALUES (1,'Zumba','Zumba es un movimiento o disciplina fitness de origen colombiano, enfocado por una parte a mantener un cuerpo saludable y por otra a desarrollar, fortalecer y dar flexibilidad al cuerpo mediante movimientos de baile combinados con una serie de rutinas aerbicas. La zumba utiliza dentro de sus rutinas los principales ritmos latinoamericanos, como lo son la salsa, el merengue, la cumbia, el reggaetn y la samba. En cada sesin de Zumba, se pueden llegar a quemar 800 caloras.',1,6);
INSERT INTO `ARCYD`.`Actividad` (`idActividad`,`nombre`,`descripcion`,`Profesor_idProfesor`,`Localizacion_idLocalizacion`) VALUES (2,'Pilates','El mtodo Pilates, o simplemente Pilates, es un sistema de entrenamiento fsico y mental creado a principios del siglo XX por Joseph Hubertus Pilates, quien lo ide basndose en su conocimiento de distintas especialidades como gimnasia, traumatologa y yoga, uniendo el dinamismo y la fuerza muscular con el control mental, la respiracin y la relajacin.',1,6);
INSERT INTO `ARCYD`.`Actividad` (`idActividad`,`nombre`,`descripcion`,`Profesor_idProfesor`,`Localizacion_idLocalizacion`) VALUES (3,'Aerobic','El aerbic o la aerbica es un tipo de deporte aerbico que se realiza al son de la msica. El aerbic rene todos los beneficios del ejercicio aerbico, adems de ejercitar capacidades fsicas como la flexibilidad, coordinacin, orientacin, ritmo, etc. ',2,6);
INSERT INTO `ARCYD`.`Actividad` (`idActividad`,`nombre`,`descripcion`,`Profesor_idProfesor`,`Localizacion_idLocalizacion`) VALUES (4,'Taichi','El tai chi o tai chi chuan es un arte marcial desarrollado en el Imperio de China, practicado actualmente por varios millones de personas en el mundo entero, por lo que se cuenta entre las artes marciales que se practican ms masivamente.',3,6);
INSERT INTO `ARCYD`.`Actividad` (`idActividad`,`nombre`,`descripcion`,`Profesor_idProfesor`,`Localizacion_idLocalizacion`) VALUES (5,'Spinning','Spinning es un programa de indoor cycling, un entrenamiento aerbico que se realiza con una bicicleta esttica al ritmo de la msica.',4,5);
INSERT INTO `ARCYD`.`Actividad` (`idActividad`,`nombre`,`descripcion`,`Profesor_idProfesor`,`Localizacion_idLocalizacion`) VALUES (6,'Gimnasia de mantenimiento','Gimnasia que engloba diferentes ejercicios',4,6);
INSERT INTO `ARCYD`.`Actividad` (`idActividad`,`nombre`,`descripcion`,`Profesor_idProfesor`,`Localizacion_idLocalizacion`) VALUES (7,'Mquinas','Bicicletas, Pesas, Bicicletas elpticas',5,5);

/*
-- Query: SELECT * FROM arcyd.HorarioActividad
LIMIT 0, 1000

-- Date: 2013-03-28 11:42
*/
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (1,'Lnes-Mircoles','18:00-19:00',1);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (2,'Martes-Jueves','17:00-18:00',1);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (3,'Lnes-Martes','19:00-20:00',2);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (4,'Mircoles-Jueves','10:00-11:00',2);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (5,'Lnes-Domingo','10:00-14:00',7);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (6,'Lnes-Sbado','16:00-20:00',7);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (7,'Mircoles-Jueves','13:00-14:00',3);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (8,'Martes-Mircoles','11:00-12:00',3);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (9,'Lnes-Jueves','11:00-12:30',4);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (10,'Lnes-Mircoles','9:00-10:00',5);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (11,'Martes-Jueves','9:00-10:00',5);
INSERT INTO `ARCYD`.`HorarioActividad` (`idHorarioActividad`,`dia`,`hora`,`Actividad_idActividad`) VALUES (12,'Viernes','10:00-12:00',6);


/*
-- Query: SELECT * FROM arcyd.Usuario
LIMIT 0, 1000

-- Date: 2013-03-28 11:43
*/
INSERT INTO `ARCYD`.`Usuario` (`idUsuario`,`numSocio`,`dni`,`nombre`,`apellido`,`direccion`,`telefono`,`email`,`password`,`perfil`) VALUES (1,'001-1','111111-L','Francisco','Prez Prez','Rubiales 34 - Getafe - Madrid','913423342','f.rubiales@gmail.com','frubiales','ROLE_USER');
INSERT INTO `ARCYD`.`Usuario` (`idUsuario`,`numSocio`,`dni`,`nombre`,`apellido`,`direccion`,`telefono`,`email`,`password`,`perfil`) VALUES (2,'001-2','3424234-A','Mara','Fernando Lpez','Rubiales 34 - Getafe - Madrid','913423342','mferlop@gmail.com','mferlo','ROLE_USER');
INSERT INTO `ARCYD`.`Usuario` (`idUsuario`,`numSocio`,`dni`,`nombre`,`apellido`,`direccion`,`telefono`,`email`,`password`,`perfil`) VALUES (3,'001-3','3423423-B','Francisco ','Prez Fernando','Rubiales 34 - Getafe - Madrid','913423342','',NULL,'ROLE_USER');
INSERT INTO `ARCYD`.`Usuario` (`idUsuario`,`numSocio`,`dni`,`nombre`,`apellido`,`direccion`,`telefono`,`email`,`password`,`perfil`) VALUES (4,'002-1','3432423-A','Mario','Ruz Sagunto','C/ Villa Florita 12 - Getafe - Madrid','6623424232','m.rui.sag@gmail.com','mruisag','ROLE_USER');
INSERT INTO `ARCYD`.`Usuario` (`idUsuario`,`numSocio`,`dni`,`nombre`,`apellido`,`direccion`,`telefono`,`email`,`password`,`perfil`) VALUES (5,'002-2','2349089-G','Mnica','Snchez Sanchez','C/ Villa Florita 12 - Getafe - Madrid','6342354333','mon.san.san@yahoo.lu','msansan','ROLE_USER');
INSERT INTO `ARCYD`.`Usuario` (`idUsuario`,`numSocio`,`dni`,`nombre`,`apellido`,`direccion`,`telefono`,`email`,`password`,`perfil`) VALUES (6,'002-2','67425469-G','Mnica','Riz Sanchez','C/ Villa Florita 12 - Getafe - Madrid','9879344332','monruisan@yahoo.lu','monruisan','ROLE_USER');
INSERT INTO `ARCYD`.`Usuario` (`idUsuario`,`numSocio`,`dni`,`nombre`,`apellido`,`direccion`,`telefono`,`email`,`password`,`perfil`) VALUES (7,'999-1','47045349-E','Eva Mara','Gonzlez San Segundo','Rue Glesener 49 - Luxembourg','691687973','evagss@uoc.edu','eva','ROLE_ADMIN');

INSERT INTO `arcyd`.`ReservaActividad` (`idReservaActividad`, `fechaInscripcion`, `EstadoReserva_idEstadoReserva`, `Usuario_idUsuario`, `Actividad_idActividad`, `HorarioActividad_idHorarioActividad`) VALUES (1,CURDATE(), 2, 1, 1, 1);
INSERT INTO `arcyd`.`ReservaActividad` (`idReservaActividad`, `fechaInscripcion`, `EstadoReserva_idEstadoReserva`, `Usuario_idUsuario`, `Actividad_idActividad`, `HorarioActividad_idHorarioActividad`) VALUES (2,CURDATE(), 2, 2, 1, 2);
INSERT INTO `arcyd`.`ReservaActividad` (`idReservaActividad`, `fechaInscripcion`, `EstadoReserva_idEstadoReserva`, `Usuario_idUsuario`, `Actividad_idActividad`, `HorarioActividad_idHorarioActividad`) VALUES (3,CURDATE(),  2, 1, 3, 7);

INSERT INTO `arcyd`.`ReservaPista` (`idReservaPista`, `Usuario_idUsuario`, `Pista_idPista`, `fechaReserva`, `horaReserva`, `EstadoReserva_idEstadoReserva`) VALUES (1, 1, 1, CURDATE(), '10:00-11:00', 2);
INSERT INTO `arcyd`.`ReservaPista` (`idReservaPista`, `Usuario_idUsuario`, `Pista_idPista`, `fechaReserva`, `horaReserva`, `EstadoReserva_idEstadoReserva`) VALUES (2, 2, 1, CURDATE(), '11:00-13:00', 2);
INSERT INTO `arcyd`.`ReservaPista` (`idReservaPista`, `Usuario_idUsuario`, `Pista_idPista`, `fechaReserva`, `horaReserva`, `EstadoReserva_idEstadoReserva`) VALUES (3, 1, 3, CURDATE(), '12:00-14:00', 2);
INSERT INTO `arcyd`.`ReservaPista` (`idReservaPista`, `Usuario_idUsuario`, `Pista_idPista`, `fechaReserva`, `horaReserva`, `EstadoReserva_idEstadoReserva`) VALUES (4, 1, 3, CURDATE(), '14:00-15:00', 2);

INSERT INTO `arcyd`.`Noticia`
(`idNoticia`,
`titulo`,
`descripcion`,
`fecha`)
VALUES
(
1,
'Cambio profesor',
'Hay un nuevo profesor de zumba',
CURDATE()
);

INSERT INTO `arcyd`.`Noticia`
(`idNoticia`,
`titulo`,
`descripcion`,
`fecha`)
VALUES
(
2,
'Adelanto clases',
'El prximo martes las clases se adelantarn una hora',
CURDATE()
);
