package arcyd.com.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.Actividad.Actividad;
import arcyd.com.model.Localizacion.Localizacion;
import arcyd.com.model.Noticia.Noticia;
import arcyd.com.model.Profesor.Profesor;
import arcyd.com.service.ActividadService;
import arcyd.com.service.HorarioActividadService;
import arcyd.com.service.NoticiaService;
import arcyd.com.service.ReservaActividadService;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class ActividadController  {

	private ActividadService actividadService;
	private ReservaActividadService reservaActividadService;
	private HorarioActividadService horarioActividadService;
	private NoticiaService noticiaService;
	@RequestMapping(value="/actividad/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit) throws Exception {

		try{

			List<Actividad> actividades = actividadService.getActividadList(start,limit);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", actividades.size());
			modelMap.put("data", actividades);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la lista de Actividades de la base de datos.");
		}
	}
	
	@RequestMapping(value="/actividad/getById.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int idActividad) throws Exception {

		try{

			Actividad actividad = actividadService.getActividadById(idActividad);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", actividad);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la actividad de la base de datos.");
		}
	}
	
	
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/actividad/create.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> create(
			@RequestParam String nombre, @RequestParam String descripcion,
			 @RequestParam int localizacion, @RequestParam int profesor) throws Exception {

		try{
			Actividad actividad = new Actividad();
			actividad.setNombre(nombre);
			actividad.setDescripcion(descripcion);
			
			Localizacion localizacionAux = new Localizacion();
			localizacionAux.setId(localizacion);
			actividad.setLocalizacion(localizacionAux);
			
			Profesor profesorAux = new Profesor();
			profesorAux.setId(profesor);
			actividad.setProfesor(profesorAux);
			
			Actividad actividades = actividadService.create(actividad);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", actividades);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error creando una actividad.");
		}
	}
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/actividad/update.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> update(
			@RequestParam int id, @RequestParam String nombre, @RequestParam String descripcion,
			 @RequestParam int localizacion, @RequestParam int profesor) throws Exception {

		try{
			Actividad actividad = actividadService.getActividadById(id);
			actividad.setNombre(nombre);
			actividad.setDescripcion(descripcion);
			
			Localizacion localizacionAux = new Localizacion();
			localizacionAux.setId(localizacion);
			actividad.setLocalizacion(localizacionAux);
			
			Profesor profesorAux = new Profesor();
			profesorAux.setId(profesor);
			actividad.setProfesor(profesorAux);
			
			Actividad actividades = actividadService.update(actividad);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", actividades);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error modificando una actividad.");
		}
	}
	
	@RequestMapping(value="/actividad/delete.action")
	public @ResponseBody Map<String,? extends Object> delete(@RequestParam int idActividad) throws Exception {
		
		try{
			Actividad actividad = actividadService.getActividadById(idActividad);
			String nombreActividad = actividad.getNombre();
			reservaActividadService.deleteByIdActividad(idActividad);
			horarioActividadService.deleteByIdActividad(idActividad);
			actividadService.delete(idActividad);

			Noticia noticia = new Noticia();
			noticia.setTitulo("Actividad cancelada");
			noticia.setDescripcion("La actividad de "+nombreActividad+" ha sido cancelada.");
			noticia.setFecha(new Date());
			
			noticiaService.create(noticia);
			
			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("success", true);

			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error eliminando la actividad.");
		}
	}
	

	@Autowired
	public void setActividadService(ActividadService actividadService) {
		this.actividadService = actividadService;
	}

	@Autowired
	public void setReservaActividadService(ReservaActividadService reservaActividadService) {
		this.reservaActividadService = reservaActividadService;
	}
	@Autowired
	public void setHorarioActividadService(HorarioActividadService horarioActividadService) {
		this.horarioActividadService = horarioActividadService;
	}
	@Autowired
	public void setNoticiaService(NoticiaService noticiaService) {
		this.noticiaService = noticiaService;
	}
	
}
