package arcyd.com.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.Actividad.Actividad;
import arcyd.com.model.HorarioActividad.HorarioActividad;
import arcyd.com.model.HorarioActividad.HorarioActividadWrapper;
import arcyd.com.model.ReservaActividad.ReservaActividad;
import arcyd.com.service.HorarioActividadService;
import arcyd.com.service.ReservaActividadService;
import arcyd.com.util.Constants;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class HorarioActividadController  {

	private HorarioActividadService horarioActividadService;
	private ReservaActividadService reservaActividadService;
	
	@RequestMapping(value="/horarioActividad/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit) throws Exception {

		try{

			List<HorarioActividad> horarioActividades = horarioActividadService.getHorarioActividadList(start,limit);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", horarioActividades.size());
			modelMap.put("data", horarioActividades);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo el listado de horarios de actividades de la base de datos.");
		}
	}
	@RequestMapping(value="/horarioActividad/getByActividadId.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int idActividad) throws Exception {

		try{

			List<HorarioActividad> horarioActividades = horarioActividadService.getHorarioByActividadId(idActividad);

			for(HorarioActividad horarioActividad : horarioActividades){
				ReservaActividad reservaActividad = new ReservaActividad();
		    	   
	    	    Actividad actividad = new Actividad();
	    	    actividad.setId(idActividad);
	    	    reservaActividad.setActividad(actividad);
	    	    
	    	    reservaActividad.setHorarioActividad(horarioActividad);
	    	    
				int numPerson = reservaActividadService.getNumPersonByActividad(reservaActividad);
				horarioActividad.setNumPersonas(numPerson);
			}
			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", horarioActividades.size());
			modelMap.put("data", horarioActividades);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo horario de actividad de la base de datos.");
		}
	}
	@RequestMapping(value="/horarioActividad/create.action")
	public @ResponseBody Map<String,? extends Object> create(@RequestParam(value = "dia") char[] dia,@RequestParam String horario, @RequestParam int actividadId) throws Exception {

		try{
			System.out.println(dia.length);
			System.out.println(horario);
			System.out.println(actividadId);
			String dias = "";
			
			String diaSeleccionadoStr="";
			for (char diaSeleccionado : dia){
				 switch(diaSeleccionado)

				 {

				 case 'L':
					 diaSeleccionadoStr = Constants.LUNES;
					 break;
				 case 'M': 
					 diaSeleccionadoStr = Constants.MARTES;
					 break;
				 case 'X': 
					 diaSeleccionadoStr = Constants.MIERCOLES;
					 break;
				 case 'J': 
					 diaSeleccionadoStr = Constants.JUEVES;
					 break;
				 case 'V': 
					 diaSeleccionadoStr = Constants.VIERNES;
					 break;
				 case 'S': 
					 diaSeleccionadoStr = Constants.SABADO;
					 break;
				 case 'D': 
					 diaSeleccionadoStr = Constants.DOMINGO;
					 break;

				 } 
				if(!"".equals(dias)){
					dias= dias+"-"+ diaSeleccionadoStr;
				}else{
					dias = diaSeleccionadoStr;
				}
			}
			HorarioActividad horarioActividad = new HorarioActividad();
			Actividad actividad = new Actividad();
			actividad.setId(actividadId);
			horarioActividad.setActividad(actividad);
			horarioActividad.setDia(dias);
			horarioActividad.setHora(horario);
			HorarioActividad horarioActividades = horarioActividadService.create(horarioActividad);
			
			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", horarioActividades);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error creando un horario de actividad.");
		}
	}
	
	
	@RequestMapping(value="/horarioActividad/update.action")
	public @ResponseBody Map<String,? extends Object> update(@RequestBody HorarioActividadWrapper data, @RequestParam int actividadId) throws Exception {
		try{
			horarioActividadService.deleteHorariosByIdActividad(actividadId);
			List <HorarioActividad>horariosActividad = data.getData();
			for(HorarioActividad horarioActividad : horariosActividad){
				Actividad actividad = new Actividad();
				actividad.setId(actividadId);
				horarioActividad.setActividad(actividad);
				horarioActividadService.create(horarioActividad);
			}
			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", horariosActividad.size());
			modelMap.put("data", horariosActividad);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error modificando un horario de actividad.");
		}
	}
	
	@RequestMapping(value="/horarioActividad/delete.action")
	public @ResponseBody Map<String,? extends Object> delete(@RequestParam int idHorarioActividad) throws Exception {
		
		try{
			
			horarioActividadService.delete(idHorarioActividad);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("success", true);

			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error eliminando horario de actividad.");
		}
	}
	

	@Autowired
	public void setHorarioActividadService(HorarioActividadService horarioActividadService) {
		this.horarioActividadService = horarioActividadService;
	}
	@Autowired
	public void setReservaActividadService(ReservaActividadService reservaActividadService) {
		this.reservaActividadService = reservaActividadService;
	}
}
