package arcyd.com.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.Noticia.Noticia;
import arcyd.com.service.NoticiaService;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class NoticiaController  {

	private NoticiaService noticiaService;
	
	@RequestMapping(value="/noticia/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit) throws Exception {

		try{

			List<Noticia> noticias = noticiaService.getNoticiaList(start,limit);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", noticias.size());
			modelMap.put("data", noticias);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la lista de noticias de la base de datos.");
		}
	}
	@RequestMapping(value="/noticia/getById.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int idNoticia) throws Exception {

		try{

			Noticia noticia = noticiaService.getNoticiaById(idNoticia);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", noticia);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo noticia de la base de datos.");
		}
	}
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/noticia/create.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> create(
			@RequestParam String titulo, @RequestParam String descripcion
			) throws Exception {

		try{
			Noticia noticia = new Noticia();
			noticia.setTitulo(titulo);
			noticia.setDescripcion(descripcion);
			noticia.setFecha(new Date());
			
			Noticia noticias = noticiaService.create(noticia);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", noticias);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error creando noticia.");
		}
	}

	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/noticia/update.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> update(
			@RequestParam int id, @RequestParam String titulo, @RequestParam String descripcion) throws Exception {
		try{

			Noticia noticia = noticiaService.getNoticiaById(id);
			noticia.setTitulo(titulo);
			noticia.setDescripcion(descripcion);
			
			
			Noticia noticias = noticiaService.update(noticia);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", noticias);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error modificando noticia.");
		}
	}
	
	@RequestMapping(value="/noticia/delete.action")
	public @ResponseBody Map<String,? extends Object> delete(@RequestParam int idNoticia) throws Exception {
		
		try{
			
			noticiaService.delete(idNoticia);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("success", true);

			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error eliminando una noticia.");
		}
	}
	

	@Autowired
	public void setNoticiaService(NoticiaService noticiaService) {
		this.noticiaService = noticiaService;
	}

}
