package arcyd.com.controller;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.Localizacion.Localizacion;
import arcyd.com.model.Noticia.Noticia;
import arcyd.com.model.Pista.Pista;
import arcyd.com.service.NoticiaService;
import arcyd.com.service.PistaService;
import arcyd.com.service.ReservaPistaService;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class PistaController  {

	private PistaService pistaService;
	private ReservaPistaService reservaPistaService;
	private NoticiaService noticiaService;
	
	@RequestMapping(value="/pista/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit) throws Exception {

		try{

			List<Pista> pistas = pistaService.getPistaList(start,limit);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", pistas.size());
			modelMap.put("data", pistas);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la lista de pistas de la base de datos.");
		}
	}
	
	@RequestMapping(value="/pista/getById.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int idPista) throws Exception {

		try{

			Pista pista = pistaService.getPistaById(idPista);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", pista);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo pista de la base de datos.");
		}
	}
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/pista/create.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> create(
			@RequestParam String nombre, @RequestParam String descripcion,
			@RequestParam int numPistas, @RequestParam int localizacion) throws Exception {

		try{
			Pista pista = new Pista();
			pista.setNombre(nombre);
			pista.setDescripcion(descripcion);
			pista.setNumPistas(numPistas);
			
			Localizacion localizacionAux = new Localizacion();
			localizacionAux.setId(localizacion);
			pista.setLocalizacion(localizacionAux);
			
			Pista pistas = pistaService.create(pista);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", pistas);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error creando pista.");
		}
	}
	
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/pista/update.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> update(
			@RequestParam int id, @RequestParam String nombre, @RequestParam String descripcion,
			@RequestParam int numPistas, @RequestParam int localizacion) throws Exception {
		try{

			Pista pista = pistaService.getPistaById(id);
			pista.setNombre(nombre);
			pista.setDescripcion(descripcion);
			pista.setNumPistas(numPistas);
			
			Localizacion localizacionAux = new Localizacion();
			localizacionAux.setId(localizacion);
			pista.setLocalizacion(localizacionAux);
			
			Pista pistas = pistaService.update(pista);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", pistas);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error modificando pista.");
		}
	}
	
	@RequestMapping(value="/pista/delete.action")
	public @ResponseBody Map<String,? extends Object> delete(@RequestParam int idPista) throws Exception {
		
		try{
			Pista pista = pistaService.getPistaById(idPista);
			String nombrePista = pista.getNombre();
			
			reservaPistaService.deleteByIdPista(idPista);
			pistaService.delete(idPista);
			
			Noticia noticia = new Noticia();
			noticia.setTitulo("Pista eliminada");
			noticia.setDescripcion("La pista de "+nombrePista+" ha sido eliminada.");
			noticia.setFecha(new Date());
			
			noticiaService.create(noticia);
			
			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("success", true);

			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error eliminando pista.");
		}
	}
	

	@Autowired
	public void setPistaService(PistaService pistaService) {
		this.pistaService = pistaService;
	}
	@Autowired
	public void setReservaPistaService(ReservaPistaService reservaPistaService) {
		this.reservaPistaService = reservaPistaService;
	}
	@Autowired
	public void setNoticiaService(NoticiaService noticiaService) {
		this.noticiaService = noticiaService;
	}
	

}
