package arcyd.com.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.Profesor.Profesor;
import arcyd.com.model.Profesor.ProfesorWrapper;
import arcyd.com.service.ProfesorService;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class ProfesorController  {

	private ProfesorService profesorService;
	
	@RequestMapping(value="/profesor/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit) throws Exception {

		try{

			List<Profesor> profesors = profesorService.getProfesorList(start,limit);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", profesors.size());
			modelMap.put("data", profesors);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la lista de profesores de la base de datos.");
		}
	}
	
	@RequestMapping(value="/profesor/create.action")
	public @ResponseBody Map<String,? extends Object> create(@RequestBody ProfesorWrapper data) throws Exception {

		try{

			Profesor profesors = profesorService.create(data.getData());

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", profesors);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error creando profesor");
		}
	}
	
	@RequestMapping(value="/profesor/update.action")
	public @ResponseBody Map<String,? extends Object> update(@RequestBody ProfesorWrapper data) throws Exception {
		try{

			Profesor profesors = profesorService.update(data.getData());

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", profesors);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error modificando profesor.");
		}
	}
	
	@RequestMapping(value="/profesor/delete.action")
	public @ResponseBody Map<String,? extends Object> delete(@RequestBody ProfesorWrapper data) throws Exception {
		
		try{
			
			profesorService.delete(data.getData());

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("success", true);

			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error eliminando profesor.");
		}
	}
	

	@Autowired
	public void setProfesorService(ProfesorService profesorService) {
		this.profesorService = profesorService;
	}

}
