package arcyd.com.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.Actividad.Actividad;
import arcyd.com.model.EstadoReserva.EstadoReserva;
import arcyd.com.model.HorarioActividad.HorarioActividad;
import arcyd.com.model.ReservaActividad.ReservaActividad;
import arcyd.com.model.Usuario.Usuario;
import arcyd.com.service.ReservaActividadService;
import arcyd.com.service.UsuarioService;
import arcyd.com.util.Constants;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class ReservaActividadController  {

	private ReservaActividadService reservaActividadService;
	private UsuarioService usuarioService;
	
	

	@RequestMapping(value="/reservaActividad/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit,
			@RequestParam(value = "id", required = false) String id,
			@RequestParam(value = "estadoreserva", required = false) String estadoreserva,
			@RequestParam(value = "nombre", required = false) String nombre, 
			@RequestParam(value = "usuarionumSocio", required = false) String usuarionumSocio) throws Exception {

		try{
			SecurityContext securityContext = SecurityContextHolder.getContext();
    	    Authentication auth =securityContext.getAuthentication();
    	    String nombreCompleto = auth.getPrincipal().toString();
    	    
    	    String numSocio = nombreCompleto.split(":")[0];
    	    numSocio= numSocio.replace(" ", "");
    	    Usuario usuario = usuarioService.getUsuarioByNumSocio(numSocio);
    	    List<ReservaActividad> reservaActividades = new ArrayList<ReservaActividad>();
    	    if(usuario!=null){
	    	    if(Constants.ROLE_USER.equals(usuario.getPerfil())){
					reservaActividades = reservaActividadService.getReservaActividadListForUsuario(start,limit,usuario.getId() );
	    	    }else {
	    	    	String usuarioToSearch = null;
	    	    	if(usuarionumSocio!=null && !"".equals(usuarionumSocio)){
	    	    		Usuario usuarioAux = usuarioService.getUsuarioByNumSocio(usuarionumSocio);
	    	    		if(usuarioAux!=null){
	    	    			usuarioToSearch = String.valueOf(usuarioAux.getId());
	    	    		}
	    	    	}
	    	    	reservaActividades = reservaActividadService.getReservaActividadList(start,limit,id,estadoreserva,nombre, usuarioToSearch);
	    	    }
    	    }

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", reservaActividades.size());
			modelMap.put("data", reservaActividades);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la lista de  Reserva Actividades de la base de datos.");
		}
	}
	
	@RequestMapping(value="/reservaActividad/cancelar.action")
	public @ResponseBody Map<String,? extends Object> cancelar(@RequestParam int idReserva) throws Exception {
		try{

			reservaActividadService.cancelar(idReserva);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 0);
			modelMap.put("data", null);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error cancelando una reserva de actividad.");
		}
	}

	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/reservaActividad/create.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> create(
			@RequestParam int id, @RequestParam int idHorarioActividad) throws Exception {

		try{

			SecurityContext securityContext = SecurityContextHolder.getContext();
    	    Authentication auth =securityContext.getAuthentication();
    	    String nombreCompleto = auth.getPrincipal().toString();
    	    String numSocio = nombreCompleto.split(":")[0];
    	    numSocio= numSocio.replace(" ", "");
    	    Usuario usuario = usuarioService.getUsuarioByNumSocio(numSocio);
    	    
    	    ReservaActividad reservaActividad = new ReservaActividad();
    	   
    	   
    	    Actividad actividad = new Actividad();
    	    actividad.setId(id);
    	    reservaActividad.setActividad(actividad);
    	    
    	    HorarioActividad horarioActividad = new HorarioActividad();
    	    horarioActividad.setId(idHorarioActividad);
    	    reservaActividad.setHorarioActividad(horarioActividad);
    	    
    	    reservaActividad.setUsuario(usuario);
    	    
    	    int numPerson = reservaActividadService.getNumPersonByActividad(reservaActividad);
    	    if(numPerson > Constants.NUM_MAX_PERSON_BY_ACTIVIDAD){
    	    	return ExtJSReturn.mapError("El nmero de personas inscritas en clase supera el mximo permitido. Seleccione otro horario u otra actividad");
    	    }else{
	    	    boolean personaYaInscritaActividad = reservaActividadService.getPersonaYaInscritaActividad(reservaActividad);
	    	    if(personaYaInscritaActividad){
	    	    	return ExtJSReturn.mapError("Ya se encuentra inscrito en esta actividad y en este horario. Seleccione otro horario u otra actividad");
	    	    }else{
		    	    EstadoReserva estadoReserva = new EstadoReserva();
		    	    estadoReserva.setId(Constants.EST_RESERVA_CONFIRMADA);
		    	    reservaActividad.setEstadoReserva(estadoReserva);
		    	    
		    	    reservaActividad.setFechaInscripcion(new Date());
		    	    
		    	    
					ReservaActividad reservaActividades = reservaActividadService.create(reservaActividad);
		
					Map<String,Object> modelMap = new HashMap<String,Object>(3);
					modelMap.put("total", 1);
					modelMap.put("data", reservaActividades);
					modelMap.put("success", true);
		    	    
					return modelMap;
	    	    }
    	    }
		} catch (Exception e) {

			return ExtJSReturn.mapError("Error generando una reserva de actividad.");
		}
	}
	

	@Autowired
	public void setReservaActividadService(ReservaActividadService reservaActividadService) {
		this.reservaActividadService = reservaActividadService;
	}
	
	/**
	 * @param usuarioService the usuarioService to set
	 */
	@Autowired
	public void setUsuarioService(UsuarioService usuarioService) {
		this.usuarioService = usuarioService;
	}

}
