package arcyd.com.controller;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.EstadoReserva.EstadoReserva;
import arcyd.com.model.Pista.Pista;
import arcyd.com.model.ReservaActividad.ReservaActividad;
import arcyd.com.model.ReservaPista.ReservaPista;
import arcyd.com.model.ReservaPista.ReservaPistaWrapper;
import arcyd.com.model.Usuario.Usuario;
import arcyd.com.service.PistaService;
import arcyd.com.service.ReservaPistaService;
import arcyd.com.service.UsuarioService;
import arcyd.com.util.Constants;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class ReservaPistaController  {

	private ReservaPistaService reservaPistaService;
	private UsuarioService usuarioService;
	private PistaService pistaService;
	
	@RequestMapping(value="/reservaPista/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit, 
			@RequestParam(value = "id", required = false) String id,
			@RequestParam(value = "estadoreserva", required = false) String estadoreserva,
			@RequestParam(value = "nombre", required = false) String nombre, 
			@RequestParam(value = "usuarionumSocio", required = false) String usuarionumSocio,
			@RequestParam(value = "datePista", required = false) String datePista) throws Exception {

		try{

			List<ReservaPista> reservaPistas = new ArrayList<ReservaPista>();
			SecurityContext securityContext = SecurityContextHolder.getContext();
    	    Authentication auth =securityContext.getAuthentication();
    	    String nombreCompleto = auth.getPrincipal().toString();
    	    String numSocio = nombreCompleto.split(":")[0];
    	    numSocio= numSocio.replace(" ", "");
    	    Usuario usuario = usuarioService.getUsuarioByNumSocio(numSocio);
    	    @SuppressWarnings("unused")
			List<ReservaActividad> reservaActividades = new ArrayList<ReservaActividad>();
    	   if(usuario != null){
	    	    if(Constants.ROLE_USER.equals(usuario.getPerfil())){
	    	    	if((nombre!=null || datePista!=null)){
	    	    		String usuarioToSearch = null;
	    	    		reservaPistas =  reservaPistaService.getReservaPistaList(start,limit,id,estadoreserva,nombre,usuarioToSearch,datePista);
	    	    		for(ReservaPista reserva: reservaPistas){
	    	    			Pista pista = pistaService.getPistaById(reserva.getPista().getId());
	    	    			int numMaximo = pista.getNumPistas();
	    	    			reserva.setNumPistas(numMaximo);
	    	    			SimpleDateFormat formatoDeFecha = new SimpleDateFormat("dd/MM/yyyy");
	    	    			String fechaReservaDate = formatoDeFecha.format(reserva.getFechaReserva());
	    	    			boolean disponible = reservaPistaService.getReservaPistaByIdAndDate(reserva.getId(), fechaReservaDate, reserva.getHoraReserva(), numMaximo);
	    	    			reserva.setDisponible(disponible);
	    	    		}
	    	    	}else{
	    	    		reservaPistas  = reservaPistaService.getReservaPistaListForUsuario(start,limit,usuario.getId() );
	    	    	}	
	    	    }else  if(Constants.ROLE_ADMIN.equals(usuario.getPerfil())){ 
	    	    	String usuarioToSearch = null;
	    	    	if(usuarionumSocio!=null && !"".equals(usuarionumSocio)){
	    	    		Usuario usuarioAux = usuarioService.getUsuarioByNumSocio(usuarionumSocio);
	    	    		if(usuarioAux!=null){
	    	    			usuarioToSearch = String.valueOf(usuarioAux.getId());
	    	    		}
	    	    	}
	    	    	
	    	    	reservaPistas =  reservaPistaService.getReservaPistaList(start,limit,id,estadoreserva,nombre,usuarioToSearch,datePista);
	    	    }
    	    }
			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", reservaPistas.size());
			modelMap.put("data", reservaPistas);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la lista de  Reservas de Pistas de la base de datos.");
		}
	}
	
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/reservaPista/create.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> create(
			@RequestParam int id, @RequestParam String fechaReserva, @RequestParam String horaReserva) throws Exception {

		try{
			SimpleDateFormat formatoDeFecha = new SimpleDateFormat("dd/MM/yyyy");
			Date fechaReservaDate = formatoDeFecha.parse(fechaReserva);
			
			Pista pista = pistaService.getPistaById(id);
			int numMaximo = pista.getNumPistas();
			
			boolean disponible = reservaPistaService.getReservaPistaByIdAndDate(id, fechaReserva, horaReserva, numMaximo);

			if(disponible){
				SecurityContext securityContext = SecurityContextHolder.getContext();
	    	    Authentication auth =securityContext.getAuthentication();
	    	    String nombreCompleto = auth.getPrincipal().toString();
	    	    String numSocio = nombreCompleto.split(":")[0];
	    	    numSocio= numSocio.replace(" ", "");
	    	    Usuario usuario = usuarioService.getUsuarioByNumSocio(numSocio);
	    	 
				ReservaPista reservaPista = new ReservaPista();
				EstadoReserva estadoReserva = new EstadoReserva();
				estadoReserva.setId(Constants.EST_RESERVA_CONFIRMADA);
				reservaPista.setEstadoReserva(estadoReserva);
				reservaPista.setPista(pista);
				reservaPista.setFechaReserva(fechaReservaDate);
				reservaPista.setHoraReserva(horaReserva);
				reservaPista.setUsuario(usuario);
				reservaPistaService.create(reservaPista);
			
				Map<String,Object> modelMap = new HashMap<String,Object>(3);
				modelMap.put("total", 1);
				modelMap.put("data", reservaPista);
				modelMap.put("success", true);
			return modelMap;
			}else{
				return ExtJSReturn.mapError("La pista que intenta reservar se encuentra ocupada.");
			}
			

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error creando la reserva de pista.");
		}
	}
	
	@RequestMapping(value="/reservaPista/update.action")
	public @ResponseBody Map<String,? extends Object> update(@RequestBody ReservaPistaWrapper data) throws Exception {
		try{

			ReservaPista reservaPistas = reservaPistaService.update(data.getData());

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", reservaPistas);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error modificando reserva pista.");
		}
	}
	@RequestMapping(value="/reservaPista/cancelar.action")
	public @ResponseBody Map<String,? extends Object> cancelar(@RequestParam int idReserva) throws Exception {
		try{

			reservaPistaService.cancelar(idReserva);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 0);
			modelMap.put("data", null);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error cancelando reserva pista.");
		}
	}
	
	@RequestMapping(value="/reservaPista/delete.action")
	public @ResponseBody Map<String,? extends Object> delete(@RequestBody ReservaPistaWrapper data) throws Exception {
		
		try{
			
			reservaPistaService.delete(data.getData());

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("success", true);

			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error eliminado reserva de Pista.");
		}
	}
	

	@Autowired
	public void setReservaPistaService(ReservaPistaService reservaPistaService) {
		this.reservaPistaService = reservaPistaService;
	}

	/**
	 * @param usuarioService the usuarioService to set
	 */
	@Autowired
	public void setUsuarioService(UsuarioService usuarioService) {
		this.usuarioService = usuarioService;
	}
	@Autowired
	public void setPistaService(PistaService pistaService) {
		this.pistaService = pistaService;
	}
}
