package arcyd.com.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import arcyd.com.model.Usuario.Usuario;
import arcyd.com.service.ReservaActividadService;
import arcyd.com.service.ReservaPistaService;
import arcyd.com.service.UsuarioService;
import arcyd.com.util.ExtJSReturn;


/**
 * Controller - Spring
 * 
 * @author Eva Maria Gonzalez

 */
@Controller
public class UsuarioController  {

	private UsuarioService usuarioService;
	private ReservaActividadService reservaActividadService;
	private ReservaPistaService reservaPistaService;
	
	@RequestMapping(value="/usuario/view.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int start, @RequestParam int limit) throws Exception {

		try{

			List<Usuario> usuarios = usuarioService.getUsuarioList(start,limit);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", usuarios.size());
			modelMap.put("data", usuarios);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo la lista de usuarios de la base de datos.");
		}
	}
	
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/usuario/create.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> create(
			@RequestParam String numSocio, @RequestParam String dni,
			@RequestParam String nombre, @RequestParam String apellido,
			@RequestParam String direccion, @RequestParam String telefono,
			@RequestParam String email, @RequestParam String password,
			@RequestParam String perfil) throws Exception {

		try{
			Usuario usuarioTest = usuarioService.getUsuarioByNumSocio(numSocio);
			if(usuarioTest!=null){
				return ExtJSReturn.mapError("Ya existe un usuario con este nmero de socio.");
			}
			Usuario usuario = new Usuario();
			usuario.setNumSocio(numSocio);
			usuario.setDni(dni);
			usuario.setNombre(nombre);
			usuario.setApellido(apellido);
			usuario.setDireccion(direccion);
			usuario.setTelefono(telefono);
			usuario.setEmail(email);
			usuario.setPerfil(perfil);
			usuario.setPassword(password);
			
			Usuario usuarios = usuarioService.create(usuario);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", usuarios);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error creando un usuario.");
		}
	}
	
	
	
	@RequestMapping(consumes = "application/x-www-form-urlencoded;charset=UTF-8", value="/usuario/update.action", method=RequestMethod.POST)
	public @ResponseBody Map<String,? extends Object> update(
			@RequestParam int id, @RequestParam String numSocio, @RequestParam String dni,
			@RequestParam String nombre, @RequestParam String apellido,
			@RequestParam String direccion, @RequestParam String telefono,
			@RequestParam String email, @RequestParam String password,
			@RequestParam String perfil) throws Exception {
		try{

			Usuario usuario = usuarioService.getUsuarioById(id);
			usuario.setNumSocio(numSocio);
			usuario.setDni(dni);
			usuario.setNombre(nombre);
			usuario.setApellido(apellido);
			usuario.setDireccion(direccion);
			usuario.setTelefono(telefono);
			usuario.setEmail(email);
			usuario.setPerfil(perfil);
			usuario.setPassword(password);
			
			Usuario usuarios = usuarioService.update(usuario);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", usuarios);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error modificando la informacin del usuario.");
		}
	}
	
	
	@RequestMapping(value="/usuario/getById.action")
	public @ResponseBody Map<String,? extends Object> view(@RequestParam int idUsuario) throws Exception {

		try{

			Usuario usuario = usuarioService.getUsuarioById(idUsuario);
			

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("total", 1);
			modelMap.put("data", usuario);
			modelMap.put("success", true);
			
			return modelMap;

		} catch (Exception e) {
			e.printStackTrace();
			return ExtJSReturn.mapError("Error obteniendo usuario.");
		}
	}
	@RequestMapping(value="/usuario/delete.action")
	public @ResponseBody Map<String,? extends Object> delete(@RequestParam int idUsuario) throws Exception {
		
		try{
			reservaActividadService.deleteByIdUserId(idUsuario);
			reservaPistaService.deleteByIdUserId(idUsuario);
			usuarioService.delete(idUsuario);

			Map<String,Object> modelMap = new HashMap<String,Object>(3);
			modelMap.put("success", true);

			return modelMap;

		} catch (Exception e) {

			return ExtJSReturn.mapError("Error eliminando usuario.");
		}
	}
	

	@Autowired
	public void setUsuarioService(UsuarioService usuarioService) {
		this.usuarioService = usuarioService;
	}
	@Autowired
	public void setReservaActividadService(ReservaActividadService reservaActividadService) {
		this.reservaActividadService = reservaActividadService;
	}
	@Autowired
	public void setReservaPistaService(ReservaPistaService reservaPistaService) {
		this.reservaPistaService = reservaPistaService;
	}

}
