package arcyd.com.dao;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.Restrictions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import arcyd.com.model.EstadoReserva.EstadoReserva;
import arcyd.com.model.ReservaActividad.ReservaActividad;
import arcyd.com.util.Constants;


/**
 * ReservaActividad DAO class.
 * 
 * @author Eva Mara Gonzlez
 * 
 */
@Repository
public class ReservaActividadDAO {

	private SessionFactory sessionFactory;
	
	@Autowired
	public void setSessionFactory(SessionFactory sessionFactory)
	{
	this.sessionFactory = sessionFactory;
	 
	}
	
	
	/**
	 * Add reservaActividad
	 * @param Actividad reservaActividad*/
	public ReservaActividad addReservaActividad(ReservaActividad reservaActividad) {
		sessionFactory.getCurrentSession().save(reservaActividad);
		return reservaActividad;
	}


	/**
	 * Delete reservaActividad 
	 * @param i 
	 * @param Actividad reservaActividad
	 */
	public void deleteReservaActividad(int id) {
		Object record = sessionFactory.getCurrentSession().load(ReservaActividad.class, id);
		sessionFactory.getCurrentSession().delete(record);
		
	}


	/**
	 * Get ReservaActividades
	 * return List ReservaActividades
	 * @param usuarioId 
	 * @param nombre 
	 * @param estadoreserva 
	 * @param id */
	@SuppressWarnings("unchecked")
	public List<ReservaActividad> getReservaActividades(int start, int limit, String id, String estadoreserva, String nombre, String usuarioToSearch) {

		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class);
		if(id!=null && !"".equals(id)){
			criteria.add(Restrictions.eq("id",Integer.parseInt(id)));
		}else{
			if(estadoreserva!=null && !"".equals(estadoreserva)){
				criteria.add(Restrictions.eq("estadoReserva.id",Integer.parseInt(estadoreserva)));
			}
			if(nombre!=null && !"".equals(nombre)){
				criteria.add(Restrictions.eq("actividad.id", Integer.parseInt(nombre)));
			}
			if(usuarioToSearch!=null && !"".equals(usuarioToSearch)){
				criteria.add(Restrictions.eq("usuario.id",Integer.parseInt(usuarioToSearch)));
			}
		}
		return criteria.list();
	}
	
	@SuppressWarnings("unchecked")
	public List<ReservaActividad> getReservaActividadesForUsuario(int start, int limit,
			int idUsuario) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class).
				add(Restrictions.eq( "usuario.id", idUsuario ));
		return criteria.list();
	}
	
	public int getNumPersonByActividad(ReservaActividad reservaActividad) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class).
				add(Restrictions.eq( "actividad.id", reservaActividad.getActividad().getId() ));
		criteria.add(Restrictions.eq( "horarioActividad.id", reservaActividad.getHorarioActividad().getId() ));
		criteria.add(Restrictions.isNull( "fechaBaja"));
		return criteria.list().size();
	}
	
	public boolean getPersonaYaInscritaActividad(ReservaActividad reservaActividad) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class).
				add(Restrictions.eq( "actividad.id", reservaActividad.getActividad().getId() ));
		criteria.add(Restrictions.eq( "usuario.id", reservaActividad.getUsuario().getId() ));
		criteria.add(Restrictions.eq( "horarioActividad.id", reservaActividad.getHorarioActividad().getId() ));
		criteria.add(Restrictions.isNull( "fechaBaja"));
		return criteria.list().size() > 0;
	}
	
	@SuppressWarnings("unchecked")
	public List<ReservaActividad> getReservaActividadesActivas(int start,
			int limit) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class).
				add(Restrictions.isNull( "fechaBaja"));
		return criteria.list();
	}
	
	/**
	 * Cancelar reservaActividad
	 * @param id reservaActividad*/
	public void cancelarReservaActividad(int idReserva) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class).
				add(Restrictions.eq( "id", idReserva ));
		@SuppressWarnings("unchecked")
		List<ReservaActividad> reservaList = criteria.list();
		ReservaActividad reserva = reservaList.get(0);
		EstadoReserva estadoReserva = new EstadoReserva();
		estadoReserva.setId(Constants.EST_RESERVA_CANCELADA);
		reserva.setEstadoReserva(estadoReserva);
		SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
		reserva.setFechaBaja(sdf.format(new Date()));
		sessionFactory.getCurrentSession().save(reserva);
		
	}
	
	public void deleteByIdActividad(int idActividad) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class).
				add(Restrictions.eq( "actividad.id", idActividad ));
		@SuppressWarnings("unchecked")
		List<ReservaActividad> reservaList = criteria.list();
		for(ReservaActividad reserva :reservaList){
			deleteReservaActividad(reserva.getId());
		}
		
	}
	
	public void deleteByIdUserId(int idUsuario) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaActividad.class).
				add(Restrictions.eq( "usuario.id", idUsuario ));
		@SuppressWarnings("unchecked")
		List<ReservaActividad> reservaList = criteria.list();
		for(ReservaActividad reserva :reservaList){
			deleteReservaActividad(reserva.getId());
		}
	}
	/**
	 * Obtiene el nmero total de reservaActividades de la base de datos
	 * @return
	 */
	public int getTotalReservaActividades(){
		return 0;
		//return DataAccessUtils.intResult(sessionFactory.getCurrentSession().find("SELECT COUNT(*) FROM ReservaActividad"));
	}

}
