package arcyd.com.dao;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.Restrictions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import arcyd.com.model.EstadoReserva.EstadoReserva;
import arcyd.com.model.ReservaPista.ReservaPista;
import arcyd.com.util.Constants;


/**
 * ReservaPista DAO class.
 * 
 * @author Eva Mara Gonzlez
 * 
 */
@Repository
public class ReservaPistaDAO {

	private SessionFactory sessionFactory;
	
	@Autowired
	public void setSessionFactory(SessionFactory sessionFactory)
	{
	this.sessionFactory = sessionFactory;
	 
	}
	
	
	/**
	 * Add reservaPista
	 * @param Actividad reservaPista*/
	public ReservaPista addReservaPista(ReservaPista reservaPista) {
		sessionFactory.getCurrentSession().save(reservaPista);
		return reservaPista;
	}
	/**
	 * Cancelar reservaPista
	 * @param id reservaPista*/
	public void cancelarReservaPista(int idReserva) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaPista.class).
				add(Restrictions.eq( "id", idReserva ));
		@SuppressWarnings("unchecked")
		List<ReservaPista> reservaList = criteria.list();
		ReservaPista reserva = reservaList.get(0);
		EstadoReserva estadoReserva = new EstadoReserva();
		estadoReserva.setId(Constants.EST_RESERVA_CANCELADA);
		reserva.setEstadoReserva(estadoReserva);
		
		sessionFactory.getCurrentSession().save(reserva);
		
	}

	/**
	 * Cancelar reservaPista
	 * @param id idPista*/
	public void deleteReservaPistaByIdPista(int idPista) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaPista.class).
				add(Restrictions.eq( "pista.id", idPista ));
		@SuppressWarnings("unchecked")
		List<ReservaPista> reservaList = criteria.list();
		for(ReservaPista reserva :reservaList){
			deleteReservaPista(reserva.getId());
		}
		
	}
	
	public void deleteByIdUserId(int idUsuario) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaPista.class).
				add(Restrictions.eq( "usuario.id", idUsuario ));
		@SuppressWarnings("unchecked")
		List<ReservaPista> reservaList = criteria.list();
		for(ReservaPista reserva :reservaList){
			deleteReservaPista(reserva.getId());
		}
		
	}
	
	public boolean getReservaPistaByIdAndDate(int id, String fechaReserva,
			String horaReserva, int numMaximo) {

		boolean disponible = true;
		SimpleDateFormat formatter = new SimpleDateFormat("dd/MM/yyyy");
	    Date dateReserva = null;
		try {
			dateReserva = formatter.parse(fechaReserva);
		} catch (ParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaPista.class).
				add(Restrictions.eq( "pista.id", id ));
		criteria.add(Restrictions.eq("fechaReserva", dateReserva));
		criteria.add(Restrictions.ne("estadoReserva.id", Constants.EST_RESERVA_CANCELADA));
		@SuppressWarnings("unchecked")
		List<ReservaPista> reservaList = criteria.list();
		String [] hora = horaReserva.split("-");
		String horaInicio = hora[0];
		String horaFin = hora[1];
		if(reservaList != null && reservaList.size()> numMaximo){
			for(ReservaPista reserva:reservaList){
				String horaReservaCompleta = reserva.getHoraReserva();
				String [] horaReservaCompletaStr = horaReservaCompleta.split("-");
				String horaInicioCompleta = horaReservaCompletaStr[0];
				String horaFinCompleta = horaReservaCompletaStr[1];
				if(horaInicio.compareTo(horaInicioCompleta)==0 ||  horaInicio.compareTo(horaFinCompleta)==0){
					disponible = false;
					return disponible;
				}
				else if(horaFin.compareTo(horaInicioCompleta)==0 || horaFin.compareTo(horaFinCompleta)==0){
					disponible = false;
					return disponible;
				}else if((horaInicio.compareTo(horaInicioCompleta)>0 &&  horaInicio.compareTo(horaFinCompleta)<0) ||
						(horaInicioCompleta.compareTo(horaInicio)>0 &&  horaInicioCompleta.compareTo(horaInicio)<0)){
					disponible = false;
					return disponible;
				}
				else if((horaFin.compareTo(horaInicioCompleta)>0 && horaFin.compareTo(horaFinCompleta)<0)||
						(horaFinCompleta.compareTo(horaInicio)>0 && horaFinCompleta.compareTo(horaFin)<0)){
					disponible = false;
					return disponible;
				}
			}
		}
		return disponible;
	}
	/**
	 * Update reservaPista
	 * @param Actividad reservaPista*/
	public ReservaPista updateReservaPista(ReservaPista reservaPista) {
		sessionFactory.getCurrentSession().save(reservaPista);
		return reservaPista;
		
	}
	/**
	 * Delete reservaPista 
	 * @param i 
	 * @param Actividad reservaPista
	 */
	public void deleteReservaPista(int id) {
		Object record = sessionFactory.getCurrentSession().load(ReservaPista.class, id);
		sessionFactory.getCurrentSession().delete(record);
		
	}


	/**
	 * Get ReservaPistas
	 * return List ReservaPistas
	 * @param usuarioToSearch 
	 * @param nombre 
	 * @param estadoreserva 
	 * @param id */
	@SuppressWarnings("unchecked")
	public List<ReservaPista> getReservaPistas(int start, int limit,
			String id, String estadoreserva, String nombre, String usuarioToSearch, String dateActividad) {

		Date dateReserva = null;
		
		if(dateActividad!=null){
			SimpleDateFormat formatter = new SimpleDateFormat("dd/MM/yyyy");
		    try {
				dateReserva = formatter.parse(dateActividad);
			} catch (ParseException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaPista.class);
		if(id!=null && !"".equals(id)){
			criteria.add(Restrictions.eq("id",Integer.parseInt(id)));
		}else{
			if(estadoreserva!=null && !"".equals(estadoreserva)){
				criteria.add(Restrictions.eq("estadoReserva.id",Integer.parseInt(estadoreserva)));
			}
			if(nombre!=null && !"".equals(nombre)){
				criteria.add(Restrictions.eq("pista.id", Integer.parseInt(nombre)));
			}
			if(usuarioToSearch!=null && !"".equals(usuarioToSearch)){
				criteria.add(Restrictions.eq("usuario.id",Integer.parseInt(usuarioToSearch)));
			}
			if(dateActividad!=null && !"".equals(dateActividad)){
				criteria.add(Restrictions.eq("fechaReserva", dateReserva));
			}
		}
		List<ReservaPista> reservaPistaList = criteria.list();
		
		return reservaPistaList;
	}
	
	
	@SuppressWarnings("unchecked")
	public List<ReservaPista> getReservaPistasForUsuario(int start, int limit,
			int idUsuario) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaPista.class).
				add(Restrictions.eq( "usuario.id", idUsuario ));
		return criteria.list();
	}
	@SuppressWarnings("unchecked")
	public List<ReservaPista> getReservaPistasActivas(int start,
			int limit) {
		Criteria criteria = sessionFactory.getCurrentSession().createCriteria(ReservaPista.class).
				add(Restrictions.ne( "estadoReserva.id",Constants.EST_RESERVA_CANCELADA));
		return criteria.list();
	}
	
	
	/**
	 * Obtiene el nmero total de reservaPistas de la base de datos
	 * @return
	 */
	public int getTotalReservaPistas(){
		return 0;
		//return DataAccessUtils.intResult(sessionFactory.getCurrentSession().find("SELECT COUNT(*) FROM ReservaPista"));
	}


}
