package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.ActividadDAO;
import arcyd.com.model.Actividad.Actividad;


/**
 * Actividad Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class ActividadService {	
	
	private ActividadDAO actividadDAO;

	/**
	 * Obtener todos los actividades
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<Actividad> getActividadList(int start, int limit){
		
		return actividadDAO.getActividades(start, limit);
	}
	@Transactional
	public Actividad getActividadById(int idActividad) {
		return actividadDAO.getActividadById(idActividad);
	}
	/**
	 * Crea un nuevo actividad
	 * @param data - json data from request
	 * @return el nuevo actividad creado
	 */
	@Transactional
	public Actividad create(Actividad actividad){
		
		return actividadDAO.addActividad(actividad);
		
	}
	
	
	/**
	 * Modifica un actividad existente
	 * @param data - json data from request
	 * @return el actividad modificado
	 */
	@Transactional
	public Actividad update(Actividad contact){
		
		return actividadDAO.updateActividad(contact);
		
	}
	
	/**
	 * Delete actividad
	 * @param idActividad - json data from request
	 */
	@Transactional
	public void delete(int idActividad){
		
		actividadDAO.deleteActividad(idActividad);
	}
	
	/**
	 * Get numero total de  Actividades 
	 * @return
	 */
	@Transactional
	public int getTotalActividades(){
	
		return actividadDAO.getTotalActividades();
	}
	
	/**
	 * Spring use - DI
	 * @param actividadDAO
	 */
	@Autowired
	public void setActividadDAO(ActividadDAO actividadDAO) {
		this.actividadDAO = actividadDAO;
	}

	/**
	 * @return the actividadDAO
	 */
	public ActividadDAO getActividadDAO() {
		return actividadDAO;
	}

	
	
	
}
