package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.HorarioActividadDAO;
import arcyd.com.model.HorarioActividad.HorarioActividad;


/**
 * HorarioActividad Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class HorarioActividadService {	
	
	private HorarioActividadDAO horarioActividadDAO;

	/**
	 * Obtener todos los horarioActividades
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<HorarioActividad> getHorarioActividadList(int start, int limit){
		
		return horarioActividadDAO.getHorarioActividades(start, limit);
	}
	
	@Transactional
	public List<HorarioActividad> getHorarioByActividadId(int idActividad) {
		return horarioActividadDAO.getHorarioByActividadId(idActividad);
	}
	/**
	 * Crea un nuevo horarioActividad
	 * @param data - json data from request
	 * @return el nuevo horarioActividad creado
	 */
	@Transactional
	public HorarioActividad create(HorarioActividad horarioActividad){
		
		return horarioActividadDAO.addHorarioActividad(horarioActividad);
		
	}
	@Transactional
	public void deleteHorariosByIdActividad(int actividadId) {
		horarioActividadDAO.deleteHorariosByIdActividad(actividadId);
		
	}
	
	/**
	 * Modifica un horarioActividad existente
	 * @param data - json data from request
	 * @return el horarioActividad modificado
	 */
	@Transactional
	public HorarioActividad update(HorarioActividad contact){
		
		return horarioActividadDAO.updateHorarioActividad(contact);
		
	}
	
	/**
	 * Delete horarioActividad
	 * @param idHorarioActividad - json data from request
	 */
	@Transactional
	public void delete(int idHorarioActividad){
		
		horarioActividadDAO.deleteHorarioActividad(idHorarioActividad);
	}
	@Transactional
	public void deleteByIdActividad(int idActividad) {
		horarioActividadDAO.deleteHorariosByIdActividad(idActividad);
		
	}
	/**
	 * Get numero total de  HorarioActividades 
	 * @return
	 */
	@Transactional
	public int getTotalHorarioActividades(){
	
		return horarioActividadDAO.getTotalHorarioActividades();
	}
	
	/**
	 * Spring use - DI
	 * @param horarioActividadDAO
	 */
	@Autowired
	public void setHorarioActividadDAO(HorarioActividadDAO horarioActividadDAO) {
		this.horarioActividadDAO = horarioActividadDAO;
	}

	/**
	 * @return the horarioActividadDAO
	 */
	public HorarioActividadDAO getHorarioActividadDAO() {
		return horarioActividadDAO;
	}

	

	
	
	
}
