package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.NoticiaDAO;
import arcyd.com.model.Noticia.Noticia;


/**
 * Socio Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class NoticiaService {	
	
	private NoticiaDAO noticiaDAO;

	/**
	 * Obtener todas las noticias
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<Noticia> getNoticiaList(int start, int limit){
		
		return noticiaDAO.getNoticias(start, limit);
	}
	
	
	/**
	 * Modifica una noticia existente
	 * @param data - json data from request
	 * @return el noticia modificada
	 */
	@Transactional
	public Noticia update(Noticia noticia){
		
		return noticiaDAO.updateNoticia(noticia);
		
	}
	@Transactional
	public Noticia getNoticiaById(int idNoticia) {
		return noticiaDAO.getNoticiaById(idNoticia);
	}
	/**
	 * Crea una nueva noticia
	 * @param data - json data from request
	 * @return la nueva noticia creada
	 */
	@Transactional
	public Noticia create(Noticia noticia){
		
		return noticiaDAO.addNoticia(noticia);
		
	}
	
	/**
	 * Delete noticia
	 * @param idNoticia - json data from request
	 */
	@Transactional
	public void delete(int idNoticia){
		
		noticiaDAO.deleteNoticia(idNoticia);
	}
	
	/**
	 * Get numero total de  Noticias 
	 * @return
	 */
	@Transactional
	public int getTotalNoticias(){
	
		return noticiaDAO.getTotalNoticias();
	}
	
	/**
	 * Spring use - DI
	 * @param noticiaDAO
	 */
	@Autowired
	public void setNoticiaDAO(NoticiaDAO noticiaDAO) {
		this.noticiaDAO = noticiaDAO;
	}

	/**
	 * @return the noticiaDAO
	 */
	public NoticiaDAO getNoticiaDAO() {
		return noticiaDAO;
	}
	
	
}
