package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.PistaDAO;
import arcyd.com.model.Pista.Pista;


/**
 * Pista Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class PistaService {	
	
	private PistaDAO pistaDAO;

	/**
	 * Obtener todos los pistas
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<Pista> getPistaList(int start, int limit){
		
		return pistaDAO.getPistas(start, limit);
	}
	
	/**
	 * Crea un nuevo pista
	 * @param data - json data from request
	 * @return el nuevo pista creado
	 */
	@Transactional
	public Pista create(Pista pista){
		
		return pistaDAO.addPista(pista);
		
	}
	
	
	/**
	 * Modifica un pista existente
	 * @param data - json data from request
	 * @return el pista modificado
	 */
	@Transactional
	public Pista update(Pista pista){
		
		return pistaDAO.updatePista(pista);
		
	}
	
	/**
	 * Delete pista
	 * @param idPista - json data from request
	 */
	@Transactional
	public void delete(int idPista){
		
		pistaDAO.deletePista(idPista);
	}
	
	/**
	 * Get numero total de  Pistas 
	 * @return
	 */
	@Transactional
	public int getTotalPistas(){
	
		return pistaDAO.getTotalPistas();
	}
	
	@Transactional
	public Pista getPistaById(int idPista) {
		return pistaDAO.getPistaById(idPista);
	}
	/**
	 * Spring use - DI
	 * @param pistaDAO
	 */
	@Autowired
	public void setPistaDAO(PistaDAO pistaDAO) {
		this.pistaDAO = pistaDAO;
	}

	/**
	 * @return the pistaDAO
	 */
	public PistaDAO getPistaDAO() {
		return pistaDAO;
	}
	
	
}
