package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.ProfesorDAO;
import arcyd.com.model.Profesor.Profesor;


/**
 * Profesor Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class ProfesorService {	
	
	private ProfesorDAO profesorDAO;

	/**
	 * Obtener todos los profesors
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<Profesor> getProfesorList(int start, int limit){
		
		return profesorDAO.getProfesores(start, limit);
	}
	
	/**
	 * Crea un nuevo profesor
	 * @param data - json data from request
	 * @return el nuevo profesor creado
	 */
	@Transactional
	public Profesor create(Profesor profesor){
		
		return profesorDAO.addProfesor(profesor);
		
	}
	
	
	/**
	 * Modifica un profesor existente
	 * @param data - json data from request
	 * @return el profesor modificado
	 */
	@Transactional
	public Profesor update(Profesor contact){
		
		return profesorDAO.updateProfesor(contact);
		
	}
	
	/**
	 * Delete profesor
	 * @param profesor - json data from request
	 */
	@Transactional
	public void delete(Profesor profesor){
		
		profesorDAO.deleteProfesor(profesor.getId());
	}
	
	/**
	 * Get numero total de  Profesores 
	 * @return
	 */
	@Transactional
	public int getTotalProfesores(){
	
		return profesorDAO.getTotalProfesores();
	}
	
	/**
	 * Spring use - DI
	 * @param profesorDAO
	 */
	@Autowired
	public void setProfesorDAO(ProfesorDAO profesorDAO) {
		this.profesorDAO = profesorDAO;
	}

	/**
	 * @return the profesorDAO
	 */
	public ProfesorDAO getProfesorDAO() {
		return profesorDAO;
	}
	
	
}
