package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.ReservaActividadDAO;
import arcyd.com.model.ReservaActividad.ReservaActividad;


/**
 * ReservaActividad Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class ReservaActividadService {	
	
	private ReservaActividadDAO reservaActividadDAO;

	/**
	 * Obtener todos los reservaActividades
	 * @param usuarioToSearch 
	 * @param nombre 
	 * @param estadoreserva 
	 * @param id 
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<ReservaActividad> getReservaActividadList(int start, int limit, String id, String estadoreserva, String nombre, String usuarioToSearch){
		
		return reservaActividadDAO.getReservaActividades(start, limit,id,estadoreserva,nombre,usuarioToSearch);
	}
	@Transactional
	public List<ReservaActividad> getReservaActividadListForUsuario(int start,
			int limit, int idUsuario) {
		return reservaActividadDAO.getReservaActividadesForUsuario(start, limit, idUsuario);
	}
	@Transactional
	public int getNumPersonByActividad(ReservaActividad reservaActividad) {
		return reservaActividadDAO.getNumPersonByActividad(reservaActividad);
	}
	@Transactional
	public List<ReservaActividad> getReservaActividadListActivas(int start,
			int limit) {
		return reservaActividadDAO.getReservaActividadesActivas(start, limit);
	}
	/**
	 * Crea un nuevo reservaActividad
	 * @param data - json data from request
	 * @return el nuevo reservaActividad creado
	 */
	@Transactional
	public ReservaActividad create(ReservaActividad reservaActividad){
		
		return reservaActividadDAO.addReservaActividad(reservaActividad);
	}
	@Transactional
	public boolean getPersonaYaInscritaActividad(ReservaActividad reservaActividad) {
		return reservaActividadDAO.getPersonaYaInscritaActividad(reservaActividad);
	}
	
	/**
	 * Delete reservaActividad
	 * @param reservaActividad - json data from request
	 */
	@Transactional
	public void delete(ReservaActividad reservaActividad){
		
		reservaActividadDAO.deleteReservaActividad(reservaActividad.getId());
	}
	
	/**
	 * Get numero total de  ReservaActividades 
	 * @return
	 */
	@Transactional
	public int getTotalReservaActividades(){
	
		return reservaActividadDAO.getTotalReservaActividades();
	}
	@Transactional
	public void deleteByIdActividad(int idActividad) {
		reservaActividadDAO.deleteByIdActividad(idActividad);
		
	}
	@Transactional
	public void deleteByIdUserId(int idUsuario) {
		reservaActividadDAO.deleteByIdUserId(idUsuario);
	}
	
	@Transactional
	public void cancelar(int idReserva) {
		reservaActividadDAO.cancelarReservaActividad(idReserva);
	}
	/**
	 * Spring use - DI
	 * @param reservaActividadDAO
	 */
	@Autowired
	public void setReservaActividadDAO(ReservaActividadDAO reservaActividadDAO) {
		this.reservaActividadDAO = reservaActividadDAO;
	}

	/**
	 * @return the reservaActividadDAO
	 */
	public ReservaActividadDAO getReservaActividadDAO() {
		return reservaActividadDAO;
	}
	
}
