package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.ReservaPistaDAO;
import arcyd.com.model.ReservaPista.ReservaPista;


/**
 * ReservaPista Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class ReservaPistaService {	
	
	private ReservaPistaDAO reservaPistaDAO;

	/**
	 * Obtener todos los reservaPistas
	 * @param usuarionumSocio 
	 * @param nombre 
	 * @param estadoreserva 
	 * @param id 
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<ReservaPista> getReservaPistaList(int start, int limit, 
			String id, String estadoreserva, String nombre, String usuarioToSearch, String dateActividad){
		
		return reservaPistaDAO.getReservaPistas(start, limit,id,estadoreserva,nombre,usuarioToSearch, dateActividad);
	}
	
	@Transactional
	public List<ReservaPista> getReservaPistaListForUsuario(int start,
			int limit, int idUsuario) {
		return reservaPistaDAO.getReservaPistasForUsuario(start, limit, idUsuario);
	}
	
	@Transactional
	public List<ReservaPista> getReservaPistaListActivas(int start,
			int limit) {
		return reservaPistaDAO.getReservaPistasActivas(start, limit);
	}
	/**
	 * Crea un nuevo reservaPista
	 * @param data - json data from request
	 * @return el nuevo reservaPista creado
	 */
	@Transactional
	public ReservaPista create(ReservaPista reservaPista){
		
		return reservaPistaDAO.addReservaPista(reservaPista);
		
	}
	
	
	
	/**
	 * Modifica un reservaPista existente
	 * @param data - json data from request
	 * @return el reservaPista modificado
	 */
	@Transactional
	public ReservaPista update(ReservaPista contact){
		
		return reservaPistaDAO.updateReservaPista(contact);
		
	}
	/**
	 * El metodo devuelve true si la reserva se puede llevar a cabo (existen pistas disponibles)
	 * y false en caso contrario.
	 * @param id
	 * @param fechaReserva
	 * @param horaReserva
	 * @param numMaximo: Numero mximo de pistas disponibles
	 * @return true o false */
	@Transactional
	public boolean getReservaPistaByIdAndDate(int id,
			String fechaReserva, String horaReserva, int numMaximo) {
		return reservaPistaDAO.getReservaPistaByIdAndDate( id,
				 fechaReserva,  horaReserva, numMaximo);
	}
	/**
	 * Delete reservaPista
	 * @param reservaPista - json data from request
	 */
	@Transactional
	public void delete(ReservaPista reservaPista){
		
		reservaPistaDAO.deleteReservaPista(reservaPista.getId());
	}
	@Transactional
	public void cancelar(int idReserva) {
		reservaPistaDAO.cancelarReservaPista(idReserva);
	}
	@Transactional
	public void deleteByIdPista(int idPista) {
		reservaPistaDAO.deleteReservaPistaByIdPista(idPista);
		
	}
	@Transactional
	public void deleteByIdUserId(int idUsuario) {
		reservaPistaDAO.deleteByIdUserId(idUsuario);
		
	}
	/**
	 * Get numero total de  ReservaPistas 
	 * @return
	 */
	@Transactional
	public int getTotalReservaPistas(){
	
		return reservaPistaDAO.getTotalReservaPistas();
	}
	
	/**
	 * Spring use - DI
	 * @param reservaPistaDAO
	 */
	@Autowired
	public void setReservaPistaDAO(ReservaPistaDAO reservaPistaDAO) {
		this.reservaPistaDAO = reservaPistaDAO;
	}

	/**
	 * @return the reservaPistaDAO
	 */
	public ReservaPistaDAO getReservaPistaDAO() {
		return reservaPistaDAO;
	}

	

	

	
}
