package arcyd.com.service;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.AuthenticationException;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import arcyd.com.dao.UsuarioDAO;
import arcyd.com.model.Usuario.Usuario;
import arcyd.com.util.Credentials;


/**
 * Usuario Service
 * 
 * @author Eva Maria Gonzlez
 */
@Service
public class UsuarioService {	
	
	private UsuarioDAO usuarioDAO;

	/**
	 * Obtener todos los usuarios
	 * @return
	 */
	@Transactional(readOnly=true)
	public List<Usuario> getUsuarioList(int start, int limit){
		
		return usuarioDAO.getUsuarios(start, limit);
	}
	
	/**
	 * Crea un nuevo usuario
	 * @param data - json data from request
	 * @return el nuevo usuario creado
	 */
	@Transactional
	public Usuario create(Usuario usuario){
		
		return usuarioDAO.addUsuario(usuario);
		
	}
	@Transactional
	 public Usuario authenticate(Credentials userCredentials) throws AuthenticationException {
		 return usuarioDAO.getUsuario(userCredentials);
	}
	@Transactional
	 public Usuario getUsuarioByNumSocio(String numSocio)  {
		 return usuarioDAO.getUsuario(numSocio);
	}
	/**
	 * Modifica un usuario existente
	 * @param data - json data from request
	 * @return el usuario modificado
	 */
	@Transactional
	public Usuario update(Usuario usuario){
		
		return usuarioDAO.updateUsuario(usuario);
		
	}
	
	@Transactional
	public Usuario getUsuarioById(int idUsuario) {
		return usuarioDAO.getUsuarioById(idUsuario);
	}
	/**
	 * Delete usuario
	 * @param idUsuario - json data from request
	 */
	@Transactional
	public void delete(int idUsuario){
		
		usuarioDAO.deleteUsuario(idUsuario);
	}
	
	/**
	 * Get numero total de  Usuarios 
	 * @return
	 */
	@Transactional
	public int getTotalUsuarios(){
	
		return usuarioDAO.getTotalUsuarios();
	}
	
	/**
	 * Spring use - DI
	 * @param usuarioDAO
	 */
	@Autowired
	public void setUsuarioDAO(UsuarioDAO usuarioDAO) {
		this.usuarioDAO = usuarioDAO;
	}

	/**
	 * @return the usuarioDAO
	 */
	public UsuarioDAO getUsuarioDAO() {
		return usuarioDAO;
	}
	
	
}
