Ext.define('arcyd.view.pista.selectable', {
    extend: 'Ext.form.Panel',
    alias: 'widget.pistaSelectable',

    id: 'pistaSelectableForm',
    height: 459,
    autoScroll: true,
    bodyPadding: 10,
    title: '',

    initComponent: function() {
        var me = this;

        Ext.applyIf(me, {
            items: [
                {
                    xtype: 'displayfield',
                    cls: 'descriptionTitle',
                    id: 'nombreSelectablePista',
                    hideLabel: true,
                    name: 'nombre',
                    fieldStyle: 'font-size:22px;text-align:center;width:70px; color:darkblue; font-weight:bold; font-style:italic'
                },
                {
                    xtype: 'hiddenfield',
                    anchor: '100%',
                    fieldLabel: 'Label',
                    name: 'id'
                },
                {
                    xtype: 'container',
                    layout: {
                        type: 'column'
                    },
                    items: [
                        {
                            xtype: 'textareafield',
                            columnWidth: 1,
                            fieldLabel: 'Descripcion',
                            name: 'descripcion',
                            submitValue: false,
                            readOnly: true
                        }
                    ]
                },
                {
                    xtype: 'container',
                    layout: {
                        type: 'column'
                    },
                    items: [
                        {
                            xtype: 'textareafield',
                            columnWidth: 1,
                            id: 'descripcionGeneralSelectablePista',
                            fieldLabel: 'General',
                            submitValue: false,
                            readOnly: true
                        }
                    ]
                },
                {
                    xtype: 'container',
                    layout: {
                        type: 'column'
                    },
                    items: [
                        {
                            xtype: 'datefield',
                            columnWidth: 0.5,
                            id: 'fechaReservaPista',
                            fieldLabel: 'Fecha Reserva',
                            name: 'fechaReserva',
                            startDay: 1,
                            minValue: new Date(),
                            format: 'd/m/Y',
                            listeners: {
                                select: {
                                    fn: me.fechaReservaPistaSelect,
                                    scope: me
                                }
                            }
                        },
                        {
                            xtype: 'textfield',
                            columnWidth: 0.5,
                            id: 'horaReservaPista',
                            fieldLabel: 'Hora Reserva',
                            labelAlign: 'right',
                            name: 'horaReserva',
                            regex: /^([0-9]|0[0-9]|1[0-9]|2[0-3]):[0-5][0-9]-([0-9]|0[0-9]|1[0-9]|2[0-3]):[0-5][0-9]$/,
                            regexText: 'Formato hh:mm-hh:mm'
                        }
                    ]
                },
                {
                    xtype: 'container',
                    columnWidth: 1,
                    padding: 10,
                    layout: {
                        type: 'column'
                    },
                    items: [
                        {
                            xtype: 'label',
                            columnWidth: 1,
                            text: 'NOTA: Color verde significa que quedan pistas disponibles en ese horario. El rojo que en ese horario no quedan pistas disponibles.'
                        }
                    ]
                },
                {

                    xtype: 'container',
                    maxHeight: 359,
                    height:150,
                    layout: {
                        align: 'stretch',
                        pack: 'center',
                        type: 'hbox'
                    },
                    items: [
                        {
                            xtype: 'gridpanel',
                            id: 'reservasPistasViewGrid',
                            maxHeight: 259,
                            width: 450,
                            autoScroll: true,
                            title: 'Reservas de otros usuarios',
                            viewConfig: {
                                autoScroll: true,
                                getRowClass: function(record, rowIndex, rowParams, store){
                               	 var disponible = record.get('disponible');
                               	 if(disponible == true) return 'green-row';
                               	 else
                               		 return 'red-row'; // should probably conditional
                                 }
                            },
                            columns: [
				                               
				                {
				                    xtype: 'gridcolumn',
				                    dataIndex: 'id',
				                    hidden: true,
				                    hideable: false,
				                    text: 'Id'
				                },
				                {
				                    xtype: 'datecolumn',
				                    renderer: Ext.util.Format.dateRenderer('Y-m-d'),
				                    dataIndex: 'fechaReserva',
				                    text: 'Fecha Reserva',
				                    format: 'd/m/Y'
				                },
				                {
				                    xtype: 'gridcolumn',
				                    defaultWidth: 150,
				                    dataIndex: 'horaReserva',
				                    text: 'Hora Reserva'
				                },
				                {
				                    xtype: 'gridcolumn',
				                    hidden: true,
				                    defaultWidth: 150,
				                    dataIndex: 'pistaid',
				                    hideable: false,
				                    text: 'Pista '
				                },
				                {
				                    xtype: 'gridcolumn',
				                    defaultWidth: 150,
				                    flex: 1,
				                    dataIndex: 'pistanombre',
				                    text: 'Pista '
				                },
				                {
				                    xtype: 'gridcolumn',
				                    defaultWidth: 150,
				                    dataIndex: 'estadoreservaestado',
				                    text: 'Estado'
				                },
				                {
				                    xtype: 'gridcolumn',
				                    defaultWidth: 125,
				                    dataIndex: 'numPistas',
				                    text: 'Num. Pistas'
				                },
				                {
				                    xtype: 'gridcolumn',
				                    hidden: true,
				                    dataIndex: 'disponible',
				                    hideable: false,
				                    text: 'Disponible'
				                }
                            ]
                        }
                    ]
                },
                {
                    xtype: 'container',
                    height: 28,
                  
                    layout: {
                        align: 'stretch',
                        pack: 'center',
                        type: 'hbox'
                    },
                    items: [
                        {
                            xtype: 'button',
                            id: 'genericSaveBtn5',
                            style: 'margin-top: 5px',
                            enableToggle: true,
                            text: 'Reservar',
                            listeners: {
                                toggle: {
                                    fn: me.onGenericSaveBtnToggle1,
                                    scope: me
                                }
                            }
                        },
                        {
                            xtype: 'button',
                            id: 'genericCancelBtn5',
                            style: 'margin-top: 5px; margin-left: 5px;',
                            enableToggle: true,
                            text: 'Cancelar',
                            listeners: {
                                toggle: {
                                    fn: me.onGenericCancelBtnToggle11,
                                    scope: me
                                }
                            }
                        }
                    ]
                }
            ],
            errorReader: Ext.create('Ext.data.reader.Json', {
                root: 'errors'
            }),
            reader: Ext.create('Ext.data.reader.Json', {
                model: 'arcyd.model.Pista',
                root: 'data'
            })
        });

        me.callParent(arguments);
    },
    fechaReservaPistaSelect: function(dtpIssueDate, date) {

        var curr_date = date.getDate();
        var curr_month = date.getMonth() + 1; //Months are zero based
        var curr_year = date.getFullYear();
        var newDate =curr_date + "/" + curr_month + "/" + curr_year;
        var pista = Ext.getCmp('pistaListCombo');
        var idPista = '';
        if(pista!=null && pista!='' && pista != undefined) {
        	idPista = pista.getValue();
        }	
        var reservasPistasViewGrid = Ext.getCmp('reservasPistasViewGrid');
        var reservaPistasStore = Ext.create('arcyd.store.ReservaPistas');
        if(idPista!=''){
        	reservaPistasStore.proxy.extraParams.nombre = idPista;
        }
        reservaPistasStore.proxy.extraParams.datePista = newDate;
        reservasPistasViewGrid.getView().bindStore(reservaPistasStore);
        reservasPistasViewGrid.view.store.load();
      },
    onGenericSaveBtnToggle1: function(button, pressed, eOpts) {

        var pistaSelectableForm = Ext.getCmp('pistaSelectableForm');


        Ext.getCmp('pistaSelectableForm').getForm().submit({
            url:'/arcyd/reservaPista/create.action',
            method: 'POST',
            //params: {'idHorarioActividad': idHorarioActividad},
            enctype : 'multipart/form-data; charset=utf-8',
            headers: {  'Accept': 'application/json', 'content-type': 'application/x-www-form-urlencoded;charset=UTF-8' },
            success: function(form,action) {

                var jsonData = Ext.JSON.decode(action.response.responseText);
                var nombrePista = jsonData.data.pista.nombre;

                Ext.Msg.alert('Reserva Pista creada', "Reserva Pista: "+nombrePista+"generada correctamente.");
                window.location = '/arcyd/inscripciones.jsp';

            },

            failure: function(form,action){

                Ext.Msg.alert('Error en la inscripcin',action.result.message);

            }

        });

    },

    onGenericCancelBtnToggle11: function(button, pressed, eOpts) {
        window.location = '/arcyd/inscripciones.jsp';
    }

});